@@ -2,22 +2,22 @@
 
 package Validation::Class::Prototype;
 {
-    $Validation::Class::Prototype::VERSION = '7.77';
+    $Validation::Class::Prototype::VERSION = '7.78';
 }
 
 use strict;
 use warnings;
 
-our $VERSION = '7.77';    # VERSION
+our $VERSION = '7.78';    # VERSION
 
-use base 'Validation::Class::Backwards';    # I'm pro-life
+use base 'Validation::Class::Backwards';
 
 use Carp 'confess';
+use Hash::Flatten 'unflatten';
 use Hash::Merge 'merge';
 use Module::Runtime 'use_module';
-use Hash::Flatten;
-
 use Validation::Class::Base 'has', 'hold';
+
 use Validation::Class::Params;
 use Validation::Class::Errors;
 use Validation::Class::Fields;
@@ -39,37 +39,6 @@ has 'filtering' => 'pre';
 hold 'filters' => sub { {} };
 
 
-has 'hash_inflator' => sub {
-
-    my $options = @_ > 1
-      ? pop @_
-      : {
-        hash_delimiter  => '.',
-        array_delimiter => ':',
-        escape_sequence => '',
-      };
-
-    foreach my $option (keys %{$options}) {
-
-        if ($option =~ /\_/) {
-
-            my $cc_option = $option;
-
-            $cc_option =~ s/([a-zA-Z])\_([a-zA-Z])/$1\u$2/gi;
-
-            $options->{ucfirst $cc_option} = $options->{$option};
-
-            delete $options->{$option};
-
-        }
-
-    }
-
-    return $options;
-
-};
-
-
 has 'ignore_failure' => '1';
 
 
@@ -436,7 +405,6 @@ sub class {
 
     my @attrs = qw(
 
-      hash_inflator
       ignore_failure
       ignore_unknown
       report_failure
@@ -444,8 +412,6 @@ sub class {
 
       );    # to be copied (stash and params copied later)
 
-    my $delimiter = $self->hash_inflator->{'HashDelimiter'};
-
     my %defaults = (map { $_ => $self->$_ } @attrs);
 
     $defaults{'stash'} = $self->stash;    # copy stash
@@ -464,6 +430,8 @@ sub class {
 
     }
 
+    return unless $class_name->can('new');
+
     my $child = $class_name->new(%settings);
 
     {
@@ -479,11 +447,9 @@ sub class {
 
             if (defined $settings{'params'}) {
 
-                $delimiter =~ s/([\.\+\-\:\,\\\/])/\\$1/g;
-
                 foreach my $name ($proto->params->keys) {
 
-                    if ($name =~ /^$shortname$delimiter(.*)/) {
+                    if ($name =~ /^$shortname\.(.*)/) {
 
                         if ($proto->fields->has($1)) {
 
@@ -1455,26 +1421,6 @@ sub errors_to_string {
 }
 
 
-sub flatten_params {
-
-    my ($self, $params) = @_;
-
-    return undef unless "HASH" eq ref $params;
-
-    my ($ad, $hd) = @{$self->hash_inflator}{'ArrayDelimiter', 'HashDelimiter'};
-
-    my $serializer = Hash::Flatten->new($self->hash_inflator);
-
-    return grep({ref $_} values %{$params})
-      ?
-
-      # do not flatten params if suspected to have already been flattened
-      $serializer->flatten($params)
-      : $params;
-
-}
-
-
 sub get_errors {
 
     my ($self, @criteria) = @_;
@@ -1555,8 +1501,6 @@ sub get_params {
 
     my $params = $self->params->hash || {};
 
-    $params = $self->unflatten_params($params);
-
     if (@params) {
 
         return @params ? (map { $params->{$_} || undef } @params) : ();
@@ -1576,7 +1520,7 @@ sub get_value {
 
     my ($self, $name) = @_;
 
-    return undef unless $self->fields->has($name);
+    return 0 unless $self->fields->has($name);
 
     my $field = $self->fields->{$name};
 
@@ -1588,18 +1532,6 @@ sub get_value {
 
     }
 
-    else {
-
-        my $params = $self->get_params;    # unflattened params
-
-        if (exists $params->{$name}) {
-
-            $value = $params->{$name};
-
-        }
-
-    }
-
     unless (defined $value) {
 
         if (exists $field->{default}) {
@@ -1954,7 +1886,7 @@ sub param {
 
     }
 
-    return undef;
+    return 0;
 
 }
 
@@ -2046,7 +1978,6 @@ sub proxy_attributes {
 
       fields
       filtering
-      hash_inflator
       ignore_failure
       ignore_unknown
       params
@@ -2074,7 +2005,6 @@ sub proxy_methods {
       get_params
       fields
       filtering
-      hash_inflator
       ignore_failure
       ignore_unknown
       param
@@ -2245,20 +2175,12 @@ sub set_params {
 
     my $args = @_ % 2 ? $_[0] : {@_};
 
-    my $params = $self->get_params;    # unflattened params
-
     while (my ($k, $v) = each(%{$args})) {
 
-        $params->{$k} = $v;            # add new/overwrite existing
+        $self->params->add($k => $v);    # add new/overwrite existing
 
     }
 
-    $params = $self->flatten_params($params);
-
-    $self->params->clear;
-
-    $self->params->add($params);
-
     return $self;
 
 }
@@ -2285,11 +2207,7 @@ sub set_value {
 
         unless (defined $self->fields->{$name}->{readonly}) {
 
-            my $params = $self->unflatten_params($self->params->hash);
-
-            $params->{$name} = $value;
-
-            $self->set_params($name => $value);
+            $self->params->add($name => $value);
 
         }
 
@@ -2352,16 +2270,13 @@ sub throw_error {
 
 }
 
-
 sub unflatten_params {
 
     my ($self, $params) = @_;
 
-    return undef unless "HASH" eq ref $params;
+    $params ||= $self->params->hash;
 
-    my $serializer = Hash::Flatten->new($self->hash_inflator);
-
-    return $serializer->unflatten($params) || {};
+    return unflatten($params) || {};
 
 }
 
@@ -2482,14 +2397,33 @@ sub validate {
 
     if ($self->params->count) {
 
-        # check if any parameters are arrayrefs
-        # and handle them appropriately (clone, validate, then reap)
+        # flatten array params
 
-        my ($ad, $hd) = @{$self->hash_inflator}{
+        my $params = $self->params->hash;
 
-            # ^^ pun here
-            'ArrayDelimiter', 'HashDelimiter'
-          };
+        my $flatten_array_params_routine = sub {
+
+            my ($key, $value) = @_;
+
+            if ("ARRAY" eq ref $value) {
+
+                my $i = 0;
+
+                foreach my $slice (@{$value}) {
+
+                    $self->params->{"$key:" . $i++} = $slice;
+
+                }
+
+                $self->params->remove($key);
+
+            }
+
+        };
+
+        $self->params->each($flatten_array_params_routine);
+
+        # validate
 
         my %seen = ();
 
@@ -2497,7 +2431,7 @@ sub validate {
 
             my ($key, $value) = @_;
 
-            my $name = $1 if $key =~ /(.*)$ad\d+$/;
+            my $name = $1 if $key =~ /(.*):\d+$/;
 
             if (defined $name) {
 
@@ -2510,7 +2444,7 @@ sub validate {
                         $seen{$name}++;
 
                         my $varcount =
-                          scalar grep {/$name$ad\d+$/} $self->params->keys;
+                          scalar grep {/$name:\d+$/} $self->params->keys;
 
                         for (my $i = 0; $i < $varcount; $i++) {
 
@@ -2570,6 +2504,24 @@ sub validate {
 
         }
 
+        # unflatten array params
+
+        foreach my $key (sort $self->params->keys) {
+
+            my ($alt, $index) = $key =~ /(.*)\:(\d+)$/;
+
+            if ($alt && defined $index) {
+
+                my $value = $self->params->remove($key);
+
+                $self->params->{$alt} ||= [];
+
+                $self->params->{$alt}->[$index] = $value;
+
+            }
+
+        }
+
     }
 
     else {
@@ -2903,7 +2855,7 @@ Validation::Class::Prototype - Prototype and Data Validation Engine for Validati
 
 =head1 VERSION
 
-version 7.77
+version 7.78
 
 =head1 SYNOPSIS
 
@@ -3035,25 +2987,6 @@ The filters attribute returns a hashref of pre-defined filter definitions.
     my $filters = $self->filters();
     ...
 
-=head2 hash_inflator
-
-The hash_inflator attribute determines how the hash serializer (inflation/deflation)
-behaves. The value must be a hashref of L<Hash::Flatten/OPTIONS> options. Purely
-for the sake of consistency, you can use lowercase keys (with underscores) which
-will be converted to camel-cased keys before passed to the serializer.
-
-    my $self = MyApp::Validation->new(hash_inflator => {
-        hash_delimiter => '/',
-        array_delimiter => '//'
-    });
-    
-    ...
-    
-    # then, hereinafter referred to as 
-    
-    $self->hash_inflator->{HashDelimiter} = '/';
-    $self->hash_inflator->{ArrayDelimiter} = '//';
-
 =head2 ignore_failure
 
 The ignore_failure boolean determines whether your application will live or die
@@ -3310,23 +3243,6 @@ and fields using the specified delimiter (defaulting to comma-space (", ")).
     
     }
 
-=head2 flatten_params
-
-The flatten_params method accepts a single hashref and will return the
-serialized version based on the the default or custom configuration of the hash
-serializer L<Hash::Flatten> as configured via the hash_inflator() attribute.
-
-    my $params = {
-        
-        user => {
-            login => 'member',
-            password => 'abc123456'
-        }
-        
-    };
-    
-    my $serialized_params = $self->flatten_params($params);
-
 =head2 get_errors
 
 The get_errors method returns a list of combined class-and-field-level errors.
@@ -3349,8 +3265,7 @@ internally than externally.
 
 The get_params method returns the values of the parameters specified (as a list,
 in the order specified). This method will return a list of key/value pairs if
-no parameter names are passed. Note, this method always returns
-exploded/unflattened parameters.
+no parameter names are passed.
 
     if ($self->validate) {
     
@@ -3359,10 +3274,9 @@ exploded/unflattened parameters.
         my ($name, $email, $login, $password) =
             $self->get_params(qw/name email login password/);
         
-        # you should note that if the params don't exist they will return undef
-        # ... meaning you should check that it is defined before doing any
-        # comparison checking -- as doing so would generate an error
-        # e.g.
+        # you should note that if the params don't exist they will return
+        # undef meaning you should check that it is defined before doing any
+        # comparison checking as doing so would generate an error, e.g.
         
         if (defined $name) {
         
@@ -3521,13 +3435,12 @@ this_function for convenience and consistency.
 
 =head2 set_params
 
-The set_params method is responsible for setting/replacing parameters while
-ensuring that previously serialized parameters are taken into account. This
+The set_params method is responsible for setting/replacing parameters. This
 method returns the class object. This method takes a list of key/value pairs or
-a single hashref whose key should match a field's name and whose value should
+a single hashref whose keys should match field names and whose value should
 be a scalar or arrayref.
 
-    $self = $self->set_params($name => $value); # accepts hashref also
+    $self->set_params($name => $value); # accepts a hashref also
 
 =head2 set_value
 
@@ -3567,21 +3480,6 @@ into context/instance specific operations.
     
     ...
 
-=head2 unflatten_params
-
-The unflatten_params method accepts a single *flat* hashref and will return the
-expanded version based on the the default or custom configuration of the hash
-serializer L<Hash::Flatten> as configured via the hash_inflator() attribute.
-
-    my $params = {
-        'user.login' => 'member',
-        'user.password' => 'abc123456'
-    };
-    
-    $params = $self->unflatten_params($params);
-        
-    print $params->{user}->{login};
-
 =head2 validate
 
 The validate method returns true/false depending on whether all specified fields
